/* Kendal Funk and Andrew Q. Philips, "Representative Budgeting: Women Mayors
* and the Composition of Spending in Local Governments" 
* Political Research Quarterly
*
* This file replicates all statistical results and figures
*
* Last Updated: 4/12/18
* ---------------------------------------------------------------------------*/

/* Notes:
	-Users must have Clarify in their user-written ado folder. Type "findit
	estsimp" to search for and install it
	-Stata 15 used for analysis, but file should work with Stata 12+

*/
cd "~/Dropbox/Kendall-Andy/Text/PRQ/PRQ Replication"
use "Funk-Philips-PRQ.dta", clear
set seed 6930206

* Macro for tables:
global tablemaker "esttab using table_analysis1.tex, replace wide unstack se star(* 0.10 ** 0.05 *** 0.01) sca("N Obs." "N_g Municipalities" "r2 rsq" "chi2 $\chi^2$" "chi2_c Prob $ > \chi^2$") title(Women Mayors Prioritize Feminine Expenditures)"


* -------------------------------------------------------------------
* Table 2 and Figure 1
* -------------------------------------------------------------------
/* combined women's issues, masculine issues, and the unclassified categories.
*/

global Y_fe "year2006 year2007 year2008 year2009 year2010 year2011 year2012" // 2005 is omitted
global fullcontrols "pctwomencouncillors pctcouncilmayorparty mayorpartyleft   mayorsecondterm lnmayorage mayorschooling winmargin lnpop budgetpc pcttransferrev pctruralpop_sim pctwomenpop_sim IDHM_sim PIND_sim ESPVIDA_sim E_ANOSESTUDO_sim RDPC_sim T_BANAGUA_sim T_M15A17CF_sim T_ANALF15M_sim"

eststo clear

eststo: sureg (fem_mas mayorfemale $fullcontrols $Y_fe) /// 
(neut_mas mayorfemale $fullcontrols $Y_fe) 

* Table for Analysis 1
$tablemaker

* Simulation part:
estsimp sureg (fem_mas mayorfemale $fullcontrols $Y_fe) /// 
(neut_mas mayorfemale $fullcontrols $Y_fe), genname(stub_)


setx mean // set everything to means
setx mayorfemale 0 // scenario = male
setx
simqi, ev genev(fem_mas_m neut_mas_m) // E[s] | male
 
setx mayorfemale 1 // scenaro = female
simqi, ev genev(fem_mas_f neut_mas_f) // E[s] | female

* Untransformation:
gen fem_m = exp(fem_mas_m)/(1 + exp(fem_mas_m) + exp(neut_mas_m))
gen neut_m = exp(neut_mas_m)/(1 + exp(fem_mas_m) + exp(neut_mas_m))
gen mas_m = 1/(1 + exp(fem_mas_m) + exp(neut_mas_m))
gen fem_f = exp(fem_mas_f)/(1 + exp(fem_mas_f) + exp(neut_mas_f))
gen neut_f = exp(neut_mas_f)/(1 + exp(fem_mas_f) + exp(neut_mas_f))
gen mas_f = 1/(1 + exp(fem_mas_f) + exp(neut_mas_f))

* grab predicted values foreach:
foreach var of varlist fem_m neut_m mas_m fem_f neut_f mas_f	{
	_pctile `var', p(2.5,97.5) // 95% CIs
	gen `var'_ll = r(r1)
	gen `var'_ul = r(r2)
	gen `var'_mid = (`var'_ll + `var'_ul)/2	// midpoint
} 

* Turn them into a graph:
preserve
keep *ul *ll *mid
gen id = _n

gen pred_ll = .
replace pred_ll = fem_m_ll in 1 // 1 = man feminine
replace pred_ll = fem_f_ll in 2 // 2 = woman feminine
replace pred_ll = mas_m_ll in 3 // 3 = man masculine
replace pred_ll = mas_f_ll in 4 // 4 = woman reminine
replace pred_ll = neut_m_ll in 5 // 5 = man neutral
replace pred_ll = neut_f_ll in 6 // 6 = woman neutral

gen pred_ul = .
replace pred_ul = fem_m_ul in 1 // 1 = man feminine
replace pred_ul = fem_f_ul in 2 // 2 = woman feminine
replace pred_ul = mas_m_ul in 3 // 3 = man masculine
replace pred_ul = mas_f_ul in 4 // 4 = woman reminine
replace pred_ul = neut_m_ul in 5 // 5 = man neutral
replace pred_ul = neut_f_ul in 6 // 6 = woman neutral

gen midpt = .
replace midpt = fem_m_mid in 1 // 1 = man feminine
replace midpt = fem_f_mid in 2 // 2 = woman feminine
replace midpt = mas_m_mid in 3 // 3 = man masculine
replace midpt = mas_f_mid in 4 // 4 = woman reminine
replace midpt = neut_m_mid in 5 // 5 = man neutral
replace midpt = neut_f_mid in 6 // 6 = woman neutral

gen pad = . // need pad just above and below each category
replace id = .5 if id == 100 // 100 is just an arbitrary #
replace id = 2.5 if id == 101
replace id = 3.5 if id == 102
replace id = 4.5 if id == 103
replace id = 5.5 if id == 104
replace id = 6.5 if id == 105

twoway scatter pad id if id == .5 || scatter pad id if id == 2.5 || ///
rspike pred_ll pred_ul id if id == 1, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 2, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 1, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 2, msymbol(S) mcolor("27 158 119")				///
xlabel(1 "Man" 2 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.57(0.01)0.61, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Feminine")
graph save g1.gph, replace

twoway scatter pad id if id == 2.5 || scatter pad id if id == 4.5 || ///
rspike pred_ll pred_ul id if id == 3, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 4, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 3, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 4, msymbol(S) mcolor("27 158 119")				///
xlabel(3 "Man" 4 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.17(0.01)0.21, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Masculine")
graph save g2.gph, replace

twoway scatter pad id if id == 4.5 || scatter pad id if id == 6.5 || ///
rspike pred_ll pred_ul id if id == 5, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 6, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 5, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 6, msymbol(S) mcolor("27 158 119")				///
xlabel(5 "Man" 6 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.20(0.01)0.24, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Unclassified")
graph save g3.gph, replace
graph combine g1.gph g2.gph g3.gph, b1title("Mayor's Gender", size(medium))  rows(1) iscale(0.7)
*graph export "aggregatecategories_acrossgender.pdf", as(pdf) replace
restore
drop *_ul *_mid *_ll *_m *_f

* Examine substantive significance, Ibiassuce:
su $fullcontrols if ibgecode == 291200 // 
* set vars to means across 8 years
setx ($Y_fe) mean pctwomencouncillors  18.75 pctcouncilmayorparty 25 mayorpartyleft .5   mayorsecondterm 0 lnmayorage  3.76093 mayorschooling  4 winmargin 2.579556 lnpop 9.250805 budgetpc 1154.702 pcttransferrev 97.64241 pctruralpop_sim 56.84259 pctwomenpop_sim 49.17574 IDHM_sim  .5849 PIND_sim  12.298 ESPVIDA_sim 71.558 E_ANOSESTUDO_sim 8.48 RDPC_sim 326.86 T_BANAGUA_sim   77.8915 T_M15A17CF_sim 7.041 T_ANALF15M_sim  22.412
setx mayorfemale 0 // scenaro = male
simqi, ev genev(fem_mas_ibia_m neut_mas_ibia_m) // E[s] | male
setx mayorfemale 1 // scenaro = female
simqi, ev genev(fem_mas_ibia_f neut_mas_ibia_f) // E[s] | female

gen fem_m = exp(fem_mas_ibia_m)/(1 + exp(fem_mas_ibia_m) + exp(neut_mas_ibia_m))
gen neut_m = exp(neut_mas_ibia_m)/(1 + exp(fem_mas_ibia_m) + exp(neut_mas_ibia_m))
gen mas_m = 1/(1 + exp(fem_mas_ibia_m) + exp(neut_mas_ibia_m))
gen fem_f = exp(fem_mas_ibia_f)/(1 + exp(fem_mas_ibia_f) + exp(neut_mas_ibia_f))
gen neut_f = exp(neut_mas_ibia_f)/(1 + exp(fem_mas_ibia_f) + exp(neut_mas_ibia_f))
gen mas_f = 1/(1 + exp(fem_mas_ibia_f) + exp(neut_mas_ibia_f))
su fem_m neut_m mas_m fem_f neut_f mas_f // predictions | Ibiassuce vals
* Multiply proportions by total budget to see predictions:
su totalexpenditures if ibgecode == 291200
di .6038745*r(mean) - .5965609*r(mean) // (woman feminine - man feminine) = 86707.826
di  .2279079*r(mean) - .228861*r(mean) // (woman neut - man neut) = -11299.665
di .1682177*r(mean) - .174578*r(mean) // (woman masc - man masc) = -75405.79





* -------------------------------------------------------------------
* Supplemental Materials Table S1 and Figures 2 and 3
* -------------------------------------------------------------------
* Separated 7 categories: education, health, social assistance, transportation, administration, urban development, other
eststo clear

eststo: sureg (edu_oth mayorfemale $fullcontrols $Y_fe) /// 
	(hlt_oth mayorfemale $fullcontrols $Y_fe)  ///
	(asst_oth mayorfemale $fullcontrols $Y_fe)  ///
	(trp_oth mayorfemale $fullcontrols $Y_fe)  ///
	(adm_oth mayorfemale $fullcontrols $Y_fe) ///
	(urb_oth mayorfemale $fullcontrols $Y_fe) 

$tablemaker


* Simulation part:
drop stub_* // drop old sims

estsimp sureg (edu_oth mayorfemale $fullcontrols $Y_fe) /// 
	(hlt_oth mayorfemale $fullcontrols $Y_fe)  ///
	(asst_oth mayorfemale $fullcontrols $Y_fe)  ///
	(trp_oth mayorfemale $fullcontrols $Y_fe)  ///
	(adm_oth mayorfemale $fullcontrols $Y_fe) ///
	(urb_oth mayorfemale $fullcontrols $Y_fe), genname(stub_) 
	
setx mean // set everything to means
setx mayorfemale 0 // scenario = male
setx
simqi, ev genev(edu_oth_m hlt_oth_m asst_oth_m trp_oth_m adm_oth_m urb_oth_m) // E[s] | male
 
 setx mayorfemale 1 // scenaro = female
 simqi, ev genev(edu_oth_f hlt_oth_f asst_oth_f trp_oth_f adm_oth_f urb_oth_f) // E[s] | female

* un-tranformation:
gen edu_m = exp(edu_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen hlt_m = exp(hlt_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen asst_m = exp(asst_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen trp_m = exp(trp_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen urb_m = exp(urb_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen adm_m = exp(adm_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen oth_m = 1/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))

gen edu_f = exp(edu_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen hlt_f = exp(hlt_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen asst_f = exp(asst_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen trp_f = exp(trp_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen urb_f = exp(urb_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen adm_f = exp(adm_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen oth_f = 1/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))


* grab predicted values foreach:
foreach var of varlist edu_m hlt_m asst_m trp_m urb_m adm_m oth_m edu_f hlt_f asst_f trp_f urb_f adm_f oth_f	{
	_pctile `var', p(2.5,97.5) // 95% CIs
	gen `var'_ll = r(r1)
	gen `var'_ul = r(r2)
	gen `var'_mid = (`var'_ll + `var'_ul)/2	// midpoint
} 
 
* Turn them into a graph:
preserve
keep *ul *ll *mid
gen id = _n

gen pred_ll = .
replace pred_ll = edu_m_ll in 1 // 1 = Man education
replace pred_ll = edu_f_ll in 2 // 2 = Woman education
replace pred_ll = hlt_m_ll in 3 // 3 = Man health
replace pred_ll = hlt_f_ll in 4 // 4 = Woman health
replace pred_ll = asst_m_ll in 5 // 5 = Man soc assist
replace pred_ll = asst_f_ll in 6 // 6 = Woman soc assist
replace pred_ll = trp_m_ll in 7 // 7 = man transp
replace pred_ll = trp_f_ll in 8 // 8 = woman transp
replace pred_ll = urb_m_ll in 9 // 9 = man urban
replace pred_ll = urb_f_ll in 10 // 10 = woman urban
replace pred_ll = adm_m_ll in 11 // 11 = man admin
replace pred_ll = adm_f_ll in 12 // 12 = woman admin
replace pred_ll = oth_m_ll in 13 // 13 = Man other
replace pred_ll = oth_f_ll in 14 // 14 = Woman other

gen pred_ul = .
replace pred_ul = edu_m_ul in 1 // 1 = Man education
replace pred_ul = edu_f_ul in 2 // 2 = Woman education
replace pred_ul = hlt_m_ul in 3 // 3 = Man health
replace pred_ul = hlt_f_ul in 4 // 4 = Woman health
replace pred_ul = asst_m_ul in 5 // 5 = Man soc assist
replace pred_ul = asst_f_ul in 6 // 6 = Woman soc assist
replace pred_ul = trp_m_ul in 7 // 7 = man transp
replace pred_ul = trp_f_ul in 8 // 8 = woman transp
replace pred_ul = urb_m_ul in 9 // 9 = man urban
replace pred_ul = urb_f_ul in 10 // 10 = woman urban
replace pred_ul = adm_m_ul in 11 // 11 = man admin
replace pred_ul = adm_f_ul in 12 // 12 = woman admin
replace pred_ul = oth_m_ul in 13 // 13 = Man other
replace pred_ul = oth_f_ul in 14 // 14 = Woman other

gen midpt = .
replace midpt = edu_m_mid in 1 // 1 = Man education
replace midpt = edu_f_mid in 2 // 2 = Woman education
replace midpt = hlt_m_mid in 3 // 3 = Man health
replace midpt = hlt_f_mid in 4 // 4 = Woman health
replace midpt = asst_m_mid in 5 // 5 = Man soc assist
replace midpt = asst_f_mid in 6 // 6 = Woman soc assist
replace midpt = trp_m_mid in 7 // 7 = man transp
replace midpt = trp_f_mid in 8 // 8 = woman transp
replace midpt = urb_m_mid in 9 // 9 = man urban
replace midpt = urb_f_mid in 10 // 10 = woman urban
replace midpt = adm_m_mid in 11 // 11 = man admin
replace midpt = adm_f_mid in 12 // 12 = woman admin
replace midpt = oth_m_mid in 13 // 13 = Man other
replace midpt = oth_f_mid in 14 // 14 = Woman other

gen pad = . // need pad just above and below each category
replace id = .5 if id == 100 // 100 is just an arbitrary #
replace id = 2.5 if id == 101
replace id = 3.5 if id == 102
replace id = 4.5 if id == 103
replace id = 5.5 if id == 104
replace id = 6.5 if id == 105
replace id = 7.5 if id == 106
replace id = 8.5 if id == 107
replace id = 9.5 if id == 108
replace id = 10.5 if id == 109
replace id = 11.5 if id == 110
replace id = 12.5 if id == 111
replace id = 13.5 if id == 112
replace id = 14.5 if id == 113
replace id = 15.5 if id == 114


twoway scatter pad id if id == .5 || scatter pad id if id == 2.5 || ///
rspike pred_ll pred_ul id if id == 1, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 2, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 1, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 2, msymbol(S) mcolor("27 158 119")				///
xlabel(1 "Man" 2 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.32(0.01)0.35, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Education")
graph save g1.gph, replace

twoway scatter pad id if id == 2.5 || scatter pad id if id == 4.5 || ///
rspike pred_ll pred_ul id if id == 3, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 4, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 3, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 4, msymbol(S) mcolor("27 158 119")				///
xlabel(3 "Man" 4 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.22(0.01)0.25, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Health")
graph save g2.gph, replace

twoway scatter pad id if id == 4.5 || scatter pad id if id == 6.5 || ///
rspike pred_ll pred_ul id if id == 5, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 6, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 5, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 6, msymbol(S) mcolor("27 158 119")				///
xlabel(5 "Man" 6 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.03(0.0025)0.045, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Social Assistance")
graph save g3.gph, replace

twoway scatter pad id if id == 6.5 || scatter pad id if id == 8.5 || ///
rspike pred_ll pred_ul id if id == 7, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 8, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 7, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 8, msymbol(S) mcolor("27 158 119")				///
xlabel(7 "Man" 8 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.00(0.001)0.005, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Transport.")
graph save g4.gph, replace

twoway scatter pad id if id == 8.5 || scatter pad id if id == 10.5 || ///
rspike pred_ll pred_ul id if id == 9, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 10, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 9, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 10, msymbol(S) mcolor("27 158 119")				///
xlabel(9 "Man" 10 "Woman" ) ysize(7)							///
 legend(off) xtitle("") 	///
ylabel(0.04(0.005)0.06, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Urban Dev.") // ytitle("Expected Proportion of Municipal Budget")
graph save g5.gph, replace

twoway scatter pad id if id == 10.5 || scatter pad id if id == 12.5 || ///
rspike pred_ll pred_ul id if id == 11, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 12, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 11, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 12, msymbol(S) mcolor("27 158 119")				///
xlabel(11 "Man" 12 "Woman" ) ysize(7)							///
 legend(off) xtitle("") 	///
ylabel(0.17(0.005)0.19, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Administration") // ytitle("Expected Proportion of Municipal Budget")
graph save g6.gph, replace

twoway scatter pad id if id == 12.5 || scatter pad id if id == 14.5 || ///
rspike pred_ll pred_ul id if id == 13, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 14, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 13, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 14, msymbol(S) mcolor("27 158 119")				///
xlabel(13 "Man" 14 "Woman" ) ysize(7)							///
 legend(off) xtitle("") 	///
ylabel(0.15(0.005)0.17, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Other") // ytitle("Expected Proportion of Municipal Budget")
graph save g7.gph, replace

graph combine g1.gph g2.gph g3.gph, b1title("Mayor's Gender", size(medium))  rows(1) iscale(0.7) 
*graph export "6category_femininespending.pdf", as(pdf) replace
graph combine g4.gph g5.gph g6.gph g7.gph, b1title("Mayor's Gender", size(medium)) rows(1) iscale(0.7)
*graph export "6category_otherspending.pdf", as(pdf) replace

restore
drop *_ul *_mid *_ll *_m *_f


* Counterfactual 2: Mirante da Serra:
* Examine substantive significance:
su $fullcontrols if ibgecode == 110130 // 
* set vars to means across 8 years
setx ($Y_fe) mean pctwomencouncillors 15.64626 pctcouncilmayorparty 21.76871 mayorpartyleft 0  mayorsecondterm 0 lnmayorage 3.732073 mayorschooling 5.428571 winmargin 8.485757 lnpop 9.418838 budgetpc 1352.138 pcttransferrev  97.95814 pctruralpop_sim 47.42884 pctwomenpop_sim 48.85336 IDHM_sim .61705  PIND_sim  11.537 ESPVIDA_sim 72.0645 E_ANOSESTUDO_sim 9.4105 RDPC_sim  502.137  T_BANAGUA_sim 73.5185 T_M15A17CF_sim 6.515 T_ANALF15M_sim 14.4685
setx mayorfemale 0 // scenaro = male
simqi, ev genev(edu_oth_m hlt_oth_m asst_oth_m trp_oth_m adm_oth_m urb_oth_m) // E[s] | male
setx mayorfemale 1 // scenaro = female
simqi, ev genev(edu_oth_f hlt_oth_f asst_oth_f trp_oth_f adm_oth_f urb_oth_f) // E[s] | female

* un-tranformation:
gen edu_m = exp(edu_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen hlt_m = exp(hlt_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen asst_m = exp(asst_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen trp_m = exp(trp_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen urb_m = exp(urb_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen adm_m = exp(adm_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen oth_m = 1/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))

gen edu_f = exp(edu_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen hlt_f = exp(hlt_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen asst_f = exp(asst_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen trp_f = exp(trp_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen urb_f = exp(urb_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen adm_f = exp(adm_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen oth_f = 1/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))

su edu_f edu_m hlt_f hlt_m asst_f asst_m trp_f trp_m urb_f urb_m adm_f adm_m oth_f oth_m // predictions | MdS vals
* Multiply proportions by total budget to see predictions:
su totalexpenditures if ibgecode == 110130
di .3558733*r(mean) - .347584*r(mean) // (woman edu - man edu) = 129975.35 // round to 130000
di  .2310473*r(mean) - .233305*r(mean) // (woman hlt - man hlt) = -35400.498 // round to -35400
di .0333779*r(mean) - .0322344*r(mean) // (woman asst  - man asst ) = 17929.96 // round to 17900
di .0047937*r(mean) - .0083039*r(mean) // (woman trp  - man trp) = -55039.566 // round to -55050
di .0299402*r(mean) - .0322752*r(mean) // (woman urb - man urb) = -36612.554 // round to -36600
di .1899387*r(mean) - .1873443*r(mean) // (woman adm - man adm) = 40679.919 // round to 40700
di .1550288*r(mean) - .1589532*r(mean) // (woman oth - man oth) = -61534.179 // round to -61550



* -------------------------------------------------------------------
* Figures S5 and S6 (in SI)
* -------------------------------------------------------------------
* Using 7 categories, see if women councilors x woman mayor has an effect
* Simulation part:
drop stub_* // drop old sims

estsimp sureg (edu_oth mayorfemale femmayor_womencounc $fullcontrols $Y_fe) /// 
	(hlt_oth mayorfemale femmayor_womencounc $fullcontrols $Y_fe)  ///
	(asst_oth mayorfemale femmayor_womencounc $fullcontrols $Y_fe)  ///
	(trp_oth mayorfemale femmayor_womencounc $fullcontrols $Y_fe)  ///
	(adm_oth mayorfemale femmayor_womencounc $fullcontrols $Y_fe) ///
	(urb_oth mayorfemale femmayor_womencounc $fullcontrols $Y_fe), genname(stub_) 

setx mean // set everything to means

* Scen 1: E[s] | male, 10% women councilors
setx mayorfemale 0 // scenario = male
setx femmayor_womencounc 0 // scenario = male, 10% women councilors
setx pctwomencouncillors 0
setx
simqi, ev genev(edu_oth_m_lo hlt_oth_m_lo asst_oth_m_lo trp_oth_m_lo adm_oth_m_lo urb_oth_m_lo) // E[s] | male, 10% women councilors
* Scen 2: E[s] | male, 90% women councilors
setx mayorfemale 0 // scenario = male
setx femmayor_womencounc 0 // scenario = male, 90% women councilors
setx pctwomencouncillors 28.57
setx
simqi, ev genev(edu_oth_m_hi hlt_oth_m_hi asst_oth_m_hi trp_oth_m_hi adm_oth_m_hi urb_oth_m_hi) // E[s] | male, 90% women councilors
* Scen 3: E[s] | female, 10% women councilors
setx mayorfemale 1 // scenario = female
setx femmayor_womencounc 0 // scenario = female, 10% women councilors
setx pctwomencouncillors 0
setx
simqi, ev genev(edu_oth_f_lo hlt_oth_f_lo asst_oth_f_lo trp_oth_f_lo adm_oth_f_lo urb_oth_f_lo) // E[s] | female, 10% women councilors
* Scen 4: E[s] | male, 90% women councilors
setx mayorfemale 1 // scenario = female
setx femmayor_womencounc 28.57 // scenario = female, 90% women councilors
setx pctwomencouncillors 28.57
setx
simqi, ev genev(edu_oth_f_hi hlt_oth_f_hi asst_oth_f_hi trp_oth_f_hi adm_oth_f_hi urb_oth_f_hi) // E[s] | female, 90% women councilors

* un-tranformation:
foreach i in m f {
	foreach z in hi lo {
		* generate predictions
		gen edu_`i'_`z' = exp(edu_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen hlt_`i'_`z' = exp(hlt_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen asst_`i'_`z' = exp(asst_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen trp_`i'_`z' = exp(trp_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen urb_`i'_`z' = exp(urb_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen adm_`i'_`z' = exp(adm_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen oth_`i'_`z' = 1/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
	}
}

* grab predicted values foreach:
foreach var of varlist edu_m_hi - oth_f_lo	{
	_pctile `var', p(2.5,97.5) // 95% CIs
	gen `var'_ll = r(r1)
	gen `var'_ul = r(r2)
	gen `var'_mid = (`var'_ll + `var'_ul)/2	// midpoint
} 
 
* Turn them into a graph:
preserve
keep *ul *ll *mid
gen id = _n

gen pred_ll = .
replace pred_ll = edu_m_lo_ll in 1 // 1 = Man education (lo)
replace pred_ll = edu_f_lo_ll in 2 // 2 = Woman education (lo)
replace pred_ll = edu_m_hi_ll in 3 // 3 = Man education (hi)
replace pred_ll = edu_f_hi_ll in 4 // 4 = Woman education (hi)
replace pred_ll = hlt_m_lo_ll in 5 // 5 = Man health (lo)
replace pred_ll = hlt_f_lo_ll in 6 // 6 = Woman health (lo)
replace pred_ll = hlt_m_hi_ll in 7 // 7 = Man health (hi)
replace pred_ll = hlt_f_hi_ll in 8 // 8 = Woman health (hi)
replace pred_ll = asst_m_lo_ll in 9 // 9 = Man soc assist (lo)
replace pred_ll = asst_f_lo_ll in 10 // 10 = Woman soc assist (lo)
replace pred_ll = asst_m_hi_ll in 11 // 11 = Man soc assist (hi)
replace pred_ll = asst_f_hi_ll in 12 // 12 = Woman soc assist (hi)
replace pred_ll = trp_m_lo_ll in 13 // 13 = Man transp (lo)
replace pred_ll = trp_f_lo_ll in 14 // 14 = Woman transp (lo)
replace pred_ll = trp_m_hi_ll in 15 // 15 = Man transp (hi)
replace pred_ll = trp_f_hi_ll in 16 // 16 = Woman transp (hi)
replace pred_ll = urb_m_lo_ll in 17 // 17 = Man urban (lo)
replace pred_ll = urb_f_lo_ll in 18 // 18 = Woman urban (lo)
replace pred_ll = urb_m_hi_ll in 19 // 19 = Man urban (hi)
replace pred_ll = urb_f_hi_ll in 20 // 20 = Woman urban (hi)
replace pred_ll = adm_m_lo_ll in 21 // 21 = Man admin (lo)
replace pred_ll = adm_f_lo_ll in 22 // 22 = Woman admin (lo)
replace pred_ll = adm_m_hi_ll in 23 // 23 = Man admin (hi)
replace pred_ll = adm_f_hi_ll in 24 // 24 = Woman admin (hi)
replace pred_ll = oth_m_lo_ll in 25 // 25 = Man other (lo)
replace pred_ll = oth_f_lo_ll in 26 // 26 = Woman other (lo)
replace pred_ll = oth_m_hi_ll in 27 // 27 = Man other (hi)
replace pred_ll = oth_f_hi_ll in 28 // 28 = Woman other (hi)



gen pred_ul = .
replace pred_ul = edu_m_lo_ul in 1 // 1 = Man education (lo)
replace pred_ul = edu_f_lo_ul in 2 // 2 = Woman education (lo)
replace pred_ul = edu_m_hi_ul in 3 // 3 = Man education (hi)
replace pred_ul = edu_f_hi_ul in 4 // 4 = Woman education (hi)
replace pred_ul = hlt_m_lo_ul in 5 // 5 = Man health (lo)
replace pred_ul = hlt_f_lo_ul in 6 // 6 = Woman health (lo)
replace pred_ul = hlt_m_hi_ul in 7 // 7 = Man health (hi)
replace pred_ul = hlt_f_hi_ul in 8 // 8 = Woman health (hi)
replace pred_ul = asst_m_lo_ul in 9 // 9 = Man soc assist (lo)
replace pred_ul = asst_f_lo_ul in 10 // 10 = Woman soc assist (lo)
replace pred_ul = asst_m_hi_ul in 11 // 11 = Man soc assist (hi)
replace pred_ul = asst_f_hi_ul in 12 // 12 = Woman soc assist (hi)
replace pred_ul = trp_m_lo_ul in 13 // 13 = Man transp (lo)
replace pred_ul = trp_f_lo_ul in 14 // 14 = Woman transp (lo)
replace pred_ul = trp_m_hi_ul in 15 // 15 = Man transp (hi)
replace pred_ul = trp_f_hi_ul in 16 // 16 = Woman transp (hi)
replace pred_ul = urb_m_lo_ul in 17 // 17 = Man urban (lo)
replace pred_ul = urb_f_lo_ul in 18 // 18 = Woman urban (lo)
replace pred_ul = urb_m_hi_ul in 19 // 19 = Man urban (hi)
replace pred_ul = urb_f_hi_ul in 20 // 20 = Woman urban (hi)
replace pred_ul = adm_m_lo_ul in 21 // 21 = Man admin (lo)
replace pred_ul = adm_f_lo_ul in 22 // 22 = Woman admin (lo)
replace pred_ul = adm_m_hi_ul in 23 // 23 = Man admin (hi)
replace pred_ul = adm_f_hi_ul in 24 // 24 = Woman admin (hi)
replace pred_ul = oth_m_lo_ul in 25 // 25 = Man other (lo)
replace pred_ul = oth_f_lo_ul in 26 // 26 = Woman other (lo)
replace pred_ul = oth_m_hi_ul in 27 // 27 = Man other (hi)
replace pred_ul = oth_f_hi_ul in 28 // 28 = Woman other (hi)

gen midpt = .
replace midpt = edu_m_lo_mid in 1 // 1 = Man education (lo)
replace midpt = edu_f_lo_mid in 2 // 2 = Woman education (lo)
replace midpt = edu_m_hi_mid in 3 // 3 = Man education (hi)
replace midpt = edu_f_hi_mid in 4 // 4 = Woman education (hi)
replace midpt = hlt_m_lo_mid in 5 // 5 = Man health (lo)
replace midpt = hlt_f_lo_mid in 6 // 6 = Woman health (lo)
replace midpt = hlt_m_hi_mid in 7 // 7 = Man health (hi)
replace midpt = hlt_f_hi_mid in 8 // 8 = Woman health (hi)
replace midpt = asst_m_lo_mid in 9 // 9 = Man soc assist (lo)
replace midpt = asst_f_lo_mid in 10 // 10 = Woman soc assist (lo)
replace midpt = asst_m_hi_mid in 11 // 11 = Man soc assist (hi)
replace midpt = asst_f_hi_mid in 12 // 12 = Woman soc assist (hi)
replace midpt = trp_m_lo_mid in 13 // 13 = Man transp (lo)
replace midpt = trp_f_lo_mid in 14 // 14 = Woman transp (lo)
replace midpt = trp_m_hi_mid in 15 // 15 = Man transp (hi)
replace midpt = trp_f_hi_mid in 16 // 16 = Woman transp (hi)
replace midpt = urb_m_lo_mid in 17 // 17 = Man urban (lo)
replace midpt = urb_f_lo_mid in 18 // 18 = Woman urban (lo)
replace midpt = urb_m_hi_mid in 19 // 19 = Man urban (hi)
replace midpt = urb_f_hi_mid in 20 // 20 = Woman urban (hi)
replace midpt = adm_m_lo_mid in 21 // 21 = Man admin (lo)
replace midpt = adm_f_lo_mid in 22 // 22 = Woman admin (lo)
replace midpt = adm_m_hi_mid in 23 // 23 = Man admin (hi)
replace midpt = adm_f_hi_mid in 24 // 24 = Woman admin (hi)
replace midpt = oth_m_lo_mid in 25 // 25 = Man other (lo)
replace midpt = oth_f_lo_mid in 26 // 26 = Woman other (lo)
replace midpt = oth_m_hi_mid in 27 // 27 = Man other (hi)
replace midpt = oth_f_hi_mid in 28 // 28 = Woman other (hi)

gen pad = . // need pad just above and below each category
loc idval = .5
forv i = 100/128 { // 100 is just an arbitrary # away from the important ones that contain PVs
	replace id = `idval' if id == `i'
	loc idval = `idval' + 1
}

twoway scatter pad id if id == .5 || scatter pad id if id == 4.5 || ///
rspike pred_ll pred_ul id if id == 1, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 2, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 3, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 4, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 1, msymbol(T) msize(large) mcolor("117 112 179") ||         	///
scatter midpt id if id == 2, msymbol(S) msize(large) mcolor("27 158 119") ||				///
scatter midpt id if id == 3, msymbol(Th) msize(large) mcolor("117 112 179") ||         	///
scatter midpt id if id == 4, msymbol(Sh) msize(large) mcolor("27 158 119") 			///
xlabel("") ysize(7)	ytitle("Expected Proportion of Municipal Budget")	///
  xtitle("") 	///
ylabel(0.32(0.01)0.35, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Education") legend(order(7 "Man (0% W. Councilors)" 8 "Woman (0% W. Councilors)" 9 "Man (28.57% W. Councilors)" 10  "Woman (28.57% W. Councilors)") rows(4)) 
graph save g1.gph, replace

twoway scatter pad id if id == 4.5 || scatter pad id if id == 8.5 || ///
rspike pred_ll pred_ul id if id == 5, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 6, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 7, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 8, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 5, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 6, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 7, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 8, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("") ysize(7)		///
ytitle("Expected Proportion of Municipal Budget") xtitle("") 	///
ylabel(0.22(0.01)0.25, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Health") legend(order(7 "Man (0% W. Councilors)" 8 "Woman (0% W. Councilors)" 9 "Man (28.57% W. Councilors)" 10  "Woman (28.57% W. Councilors)") rows(4)) 
graph save g2.gph, replace

twoway scatter pad id if id == 8.5 || scatter pad id if id == 12.5 || ///
rspike pred_ll pred_ul id if id == 9, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 10, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 11, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 12, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 9, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 10, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 11, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 12, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("") ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") xtitle("") 	///
ylabel(0.03(0.0025)0.045, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Social Assistance") legend(order(7 "Man (0% W. Councilors)" 8 "Woman (0% W. Councilors)" 9 "Man (28.57% W. Councilors)" 10  "Woman (28.57% W. Councilors)") rows(4)) 
graph save g3.gph, replace

twoway scatter pad id if id == 12.5 || scatter pad id if id == 16.5 || ///
rspike pred_ll pred_ul id if id == 13, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 14, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 15, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 16, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 13, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 14, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 15, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 16, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel( "" ) ysize(7)											///
 xtitle("") 	///
ylabel(0.00(0.001)0.005, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Transport.") legend(order(7 "Man (0% W. Councilors)" 8 "Woman (0% W. Councilors)" 9 "Man (28.57% W. Councilors)" 10  "Woman (28.57% W. Councilors)") rows(4))
graph save g4.gph, replace

twoway scatter pad id if id == 16.5 || scatter pad id if id == 20.5 || ///
rspike pred_ll pred_ul id if id == 17, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 18, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 19, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 20, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 17, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 18, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 19, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 20, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("") ysize(7)							///
  xtitle("") 	///
ylabel(0.04(0.005)0.06, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Urban Dev.") legend(order(7 "Man (0% W. Councilors)" 8 "Woman (0% W. Councilors)" 9 "Man (28.57% W. Councilors)" 10  "Woman (28.57% W. Councilors)") rows(4))
graph save g5.gph, replace

twoway scatter pad id if id == 20.5 || scatter pad id if id == 24.5 || ///
rspike pred_ll pred_ul id if id == 21, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 22, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 23, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 24, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 21, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 22, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 23, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 24, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("" ) ysize(7)							///
 xtitle("") 	///
ylabel(0.17(0.005)0.19, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Administration") legend(order(7 "Man (0% W. Councilors)" 8 "Woman (0% W. Councilors)" 9 "Man (28.57% W. Councilors)" 10  "Woman (28.57% W. Councilors)") rows(4)) 
graph save g6.gph, replace

twoway scatter pad id if id == 24.5 || scatter pad id if id == 28.5 || ///
rspike pred_ll pred_ul id if id == 25, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 26, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 27, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 28, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 25, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 26, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 27, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 28, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("" ) ysize(7)							///
  xtitle("") 	///
ylabel(0.15(0.005)0.17, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Other") legend(order(7 "Man (0% W. Councilors)" 8 "Woman (0% W. Councilors)" 9 "Man (28.57% W. Councilors)" 10  "Woman (28.57% W. Councilors)") rows(4)) 
graph save g7.gph, replace

graph combine g1.gph g2.gph g3.gph, rows(1) iscale(0.7) 
*graph export "Text/Figures/6category_femininespending_femcouncilinter.pdf", as(pdf) replace
graph combine g4.gph g5.gph g6.gph g7.gph, rows(1) iscale(0.7)
*graph export "Text/Figures/6category_otherspending_femcouncilinter.pdf", as(pdf) replace

restore
cap drop *_ul *_mid *_ll *_m *_f



* -------------------------------------------------------------------
* Figures S8 and S9 (IN SI)
* -------------------------------------------------------------------
* Using 7 categories, see if feminine background x woman mayor has an effect
* Simulation part:
drop stub_* // drop old sims

estsimp sureg (edu_oth mayorfemale occ_fem womanmayor_femocc $fullcontrols $Y_fe) /// 
	(hlt_oth mayorfemale occ_fem womanmayor_femocc $fullcontrols $Y_fe)  ///
	(asst_oth mayorfemale occ_fem womanmayor_femocc $fullcontrols $Y_fe)  ///
	(trp_oth mayorfemale occ_fem womanmayor_femocc $fullcontrols $Y_fe)  ///
	(adm_oth mayorfemale occ_fem womanmayor_femocc $fullcontrols $Y_fe) ///
	(urb_oth mayorfemale occ_fem womanmayor_femocc $fullcontrols $Y_fe), genname(stub_) 

setx mean // set everything to means
drop *_m_lo *_m_hi *_f_lo *_f_hi // drop this stuff out from before

* Scen 1: E[s] | male, no fem occ
setx mayorfemale 0 // scenario = male
setx occ_fem 0 // scenario = male, no fem occ
setx womanmayor_femocc 0
setx
simqi, ev genev(edu_oth_m_lo hlt_oth_m_lo asst_oth_m_lo trp_oth_m_lo adm_oth_m_lo urb_oth_m_lo) // E[s] | male, no fem occ
* Scen 2: E[s] | male, fem occ
setx mayorfemale 0 // scenario = male
setx occ_fem 1 // scenario = male, fem occ
setx womanmayor_femocc 0
setx
simqi, ev genev(edu_oth_m_hi hlt_oth_m_hi asst_oth_m_hi trp_oth_m_hi adm_oth_m_hi urb_oth_m_hi) // E[s] | male, fem occ
* Scen 3: E[s] | female, no fem occ
setx mayorfemale 1 // scenario = female
setx occ_fem 0 // scenario = female, no fem occ
setx womanmayor_femocc 0
setx
simqi, ev genev(edu_oth_f_lo hlt_oth_f_lo asst_oth_f_lo trp_oth_f_lo adm_oth_f_lo urb_oth_f_lo) // E[s] | female, no fem occ
* Scen 4: E[s] | female, fem occ
setx mayorfemale 1 // scenario = female
setx occ_fem 1 // scenario = female, fem occ
setx womanmayor_femocc 1
setx
simqi, ev genev(edu_oth_f_hi hlt_oth_f_hi asst_oth_f_hi trp_oth_f_hi adm_oth_f_hi urb_oth_f_hi) // E[s] | female, fem occ

* un-tranformation:
foreach i in m f {
	foreach z in hi lo {
		* generate predictions
		gen edu_`i'_`z' = exp(edu_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen hlt_`i'_`z' = exp(hlt_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen asst_`i'_`z' = exp(asst_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen trp_`i'_`z' = exp(trp_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen urb_`i'_`z' = exp(urb_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen adm_`i'_`z' = exp(adm_oth_`i'_`z')/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
		gen oth_`i'_`z' = 1/(1+(exp(edu_oth_`i'_`z')) + (exp(hlt_oth_`i'_`z')) + (exp(asst_oth_`i'_`z')) + (exp(trp_oth_`i'_`z')) + (exp(adm_oth_`i'_`z')) + (exp(urb_oth_`i'_`z')))
	}
}

* grab predicted values foreach:
foreach var of varlist edu_m_hi - oth_f_lo	{
	_pctile `var', p(2.5,97.5) // 95% CIs
	gen `var'_ll = r(r1)
	gen `var'_ul = r(r2)
	gen `var'_mid = (`var'_ll + `var'_ul)/2	// midpoint
} 
 
* Turn them into a graph:
preserve
keep *ul *ll *mid
gen id = _n

gen pred_ll = .
replace pred_ll = edu_m_lo_ll in 1 // 1 = Man education (lo)
replace pred_ll = edu_f_lo_ll in 2 // 2 = Woman education (lo)
replace pred_ll = edu_m_hi_ll in 3 // 3 = Man education (hi)
replace pred_ll = edu_f_hi_ll in 4 // 4 = Woman education (hi)
replace pred_ll = hlt_m_lo_ll in 5 // 5 = Man health (lo)
replace pred_ll = hlt_f_lo_ll in 6 // 6 = Woman health (lo)
replace pred_ll = hlt_m_hi_ll in 7 // 7 = Man health (hi)
replace pred_ll = hlt_f_hi_ll in 8 // 8 = Woman health (hi)
replace pred_ll = asst_m_lo_ll in 9 // 9 = Man soc assist (lo)
replace pred_ll = asst_f_lo_ll in 10 // 10 = Woman soc assist (lo)
replace pred_ll = asst_m_hi_ll in 11 // 11 = Man soc assist (hi)
replace pred_ll = asst_f_hi_ll in 12 // 12 = Woman soc assist (hi)
replace pred_ll = trp_m_lo_ll in 13 // 13 = Man transp (lo)
replace pred_ll = trp_f_lo_ll in 14 // 14 = Woman transp (lo)
replace pred_ll = trp_m_hi_ll in 15 // 15 = Man transp (hi)
replace pred_ll = trp_f_hi_ll in 16 // 16 = Woman transp (hi)
replace pred_ll = urb_m_lo_ll in 17 // 17 = Man urban (lo)
replace pred_ll = urb_f_lo_ll in 18 // 18 = Woman urban (lo)
replace pred_ll = urb_m_hi_ll in 19 // 19 = Man urban (hi)
replace pred_ll = urb_f_hi_ll in 20 // 20 = Woman urban (hi)
replace pred_ll = adm_m_lo_ll in 21 // 21 = Man admin (lo)
replace pred_ll = adm_f_lo_ll in 22 // 22 = Woman admin (lo)
replace pred_ll = adm_m_hi_ll in 23 // 23 = Man admin (hi)
replace pred_ll = adm_f_hi_ll in 24 // 24 = Woman admin (hi)
replace pred_ll = oth_m_lo_ll in 25 // 25 = Man other (lo)
replace pred_ll = oth_f_lo_ll in 26 // 26 = Woman other (lo)
replace pred_ll = oth_m_hi_ll in 27 // 27 = Man other (hi)
replace pred_ll = oth_f_hi_ll in 28 // 28 = Woman other (hi)



gen pred_ul = .
replace pred_ul = edu_m_lo_ul in 1 // 1 = Man education (lo)
replace pred_ul = edu_f_lo_ul in 2 // 2 = Woman education (lo)
replace pred_ul = edu_m_hi_ul in 3 // 3 = Man education (hi)
replace pred_ul = edu_f_hi_ul in 4 // 4 = Woman education (hi)
replace pred_ul = hlt_m_lo_ul in 5 // 5 = Man health (lo)
replace pred_ul = hlt_f_lo_ul in 6 // 6 = Woman health (lo)
replace pred_ul = hlt_m_hi_ul in 7 // 7 = Man health (hi)
replace pred_ul = hlt_f_hi_ul in 8 // 8 = Woman health (hi)
replace pred_ul = asst_m_lo_ul in 9 // 9 = Man soc assist (lo)
replace pred_ul = asst_f_lo_ul in 10 // 10 = Woman soc assist (lo)
replace pred_ul = asst_m_hi_ul in 11 // 11 = Man soc assist (hi)
replace pred_ul = asst_f_hi_ul in 12 // 12 = Woman soc assist (hi)
replace pred_ul = trp_m_lo_ul in 13 // 13 = Man transp (lo)
replace pred_ul = trp_f_lo_ul in 14 // 14 = Woman transp (lo)
replace pred_ul = trp_m_hi_ul in 15 // 15 = Man transp (hi)
replace pred_ul = trp_f_hi_ul in 16 // 16 = Woman transp (hi)
replace pred_ul = urb_m_lo_ul in 17 // 17 = Man urban (lo)
replace pred_ul = urb_f_lo_ul in 18 // 18 = Woman urban (lo)
replace pred_ul = urb_m_hi_ul in 19 // 19 = Man urban (hi)
replace pred_ul = urb_f_hi_ul in 20 // 20 = Woman urban (hi)
replace pred_ul = adm_m_lo_ul in 21 // 21 = Man admin (lo)
replace pred_ul = adm_f_lo_ul in 22 // 22 = Woman admin (lo)
replace pred_ul = adm_m_hi_ul in 23 // 23 = Man admin (hi)
replace pred_ul = adm_f_hi_ul in 24 // 24 = Woman admin (hi)
replace pred_ul = oth_m_lo_ul in 25 // 25 = Man other (lo)
replace pred_ul = oth_f_lo_ul in 26 // 26 = Woman other (lo)
replace pred_ul = oth_m_hi_ul in 27 // 27 = Man other (hi)
replace pred_ul = oth_f_hi_ul in 28 // 28 = Woman other (hi)

gen midpt = .
replace midpt = edu_m_lo_mid in 1 // 1 = Man education (lo)
replace midpt = edu_f_lo_mid in 2 // 2 = Woman education (lo)
replace midpt = edu_m_hi_mid in 3 // 3 = Man education (hi)
replace midpt = edu_f_hi_mid in 4 // 4 = Woman education (hi)
replace midpt = hlt_m_lo_mid in 5 // 5 = Man health (lo)
replace midpt = hlt_f_lo_mid in 6 // 6 = Woman health (lo)
replace midpt = hlt_m_hi_mid in 7 // 7 = Man health (hi)
replace midpt = hlt_f_hi_mid in 8 // 8 = Woman health (hi)
replace midpt = asst_m_lo_mid in 9 // 9 = Man soc assist (lo)
replace midpt = asst_f_lo_mid in 10 // 10 = Woman soc assist (lo)
replace midpt = asst_m_hi_mid in 11 // 11 = Man soc assist (hi)
replace midpt = asst_f_hi_mid in 12 // 12 = Woman soc assist (hi)
replace midpt = trp_m_lo_mid in 13 // 13 = Man transp (lo)
replace midpt = trp_f_lo_mid in 14 // 14 = Woman transp (lo)
replace midpt = trp_m_hi_mid in 15 // 15 = Man transp (hi)
replace midpt = trp_f_hi_mid in 16 // 16 = Woman transp (hi)
replace midpt = urb_m_lo_mid in 17 // 17 = Man urban (lo)
replace midpt = urb_f_lo_mid in 18 // 18 = Woman urban (lo)
replace midpt = urb_m_hi_mid in 19 // 19 = Man urban (hi)
replace midpt = urb_f_hi_mid in 20 // 20 = Woman urban (hi)
replace midpt = adm_m_lo_mid in 21 // 21 = Man admin (lo)
replace midpt = adm_f_lo_mid in 22 // 22 = Woman admin (lo)
replace midpt = adm_m_hi_mid in 23 // 23 = Man admin (hi)
replace midpt = adm_f_hi_mid in 24 // 24 = Woman admin (hi)
replace midpt = oth_m_lo_mid in 25 // 25 = Man other (lo)
replace midpt = oth_f_lo_mid in 26 // 26 = Woman other (lo)
replace midpt = oth_m_hi_mid in 27 // 27 = Man other (hi)
replace midpt = oth_f_hi_mid in 28 // 28 = Woman other (hi)

gen pad = . // need pad just above and below each category
loc idval = .5
forv i = 100/128 { // 100 is just an arbitrary # away from the important ones that contain PVs
	replace id = `idval' if id == `i'
	loc idval = `idval' + 1
}


twoway scatter pad id if id == .5 || scatter pad id if id == 4.5 || ///
rspike pred_ll pred_ul id if id == 1, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 2, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 3, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 4, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 1, msymbol(T) msize(large) mcolor("117 112 179") ||         	///
scatter midpt id if id == 2, msymbol(S) msize(large) mcolor("27 158 119") ||				///
scatter midpt id if id == 3, msymbol(Th) msize(large) mcolor("117 112 179") ||         	///
scatter midpt id if id == 4, msymbol(Sh) msize(large) mcolor("27 158 119") 			///
xlabel("") ysize(7)	ytitle("Expected Proportion of Municipal Budget")	///
  xtitle("") 	///
ylabel(0.32(0.01)0.35, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Education") legend(order(7 "Man (No Fem. Occ)" 8 "Woman (No Fem. Occ)" 9 "Man (Fem. Occ)" 10  "Woman (Fem. Occ)") rows(4)) 
graph save g1.gph, replace

twoway scatter pad id if id == 4.5 || scatter pad id if id == 8.5 || ///
rspike pred_ll pred_ul id if id == 5, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 6, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 7, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 8, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 5, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 6, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 7, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 8, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("") ysize(7)		///
ytitle("Expected Proportion of Municipal Budget") xtitle("") 	///
ylabel(0.22(0.01)0.25, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Health") legend(order(7 "Man (No Fem. Occ)" 8 "Woman (No Fem. Occ)" 9 "Man (Fem. Occ)" 10  "Woman (Fem. Occ)") rows(4)) 
graph save g2.gph, replace

twoway scatter pad id if id == 8.5 || scatter pad id if id == 12.5 || ///
rspike pred_ll pred_ul id if id == 9, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 10, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 11, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 12, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 9, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 10, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 11, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 12, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("") ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") xtitle("") 	///
ylabel(0.03(0.0025)0.045, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Social Assistance") legend(order(7 "Man (No Fem. Occ)" 8 "Woman (No Fem. Occ)" 9 "Man (Fem. Occ)" 10  "Woman (Fem. Occ)") rows(4))
graph save g3.gph, replace

twoway scatter pad id if id == 12.5 || scatter pad id if id == 16.5 || ///
rspike pred_ll pred_ul id if id == 13, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 14, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 15, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 16, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 13, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 14, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 15, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 16, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel( "" ) ysize(7)											///
 xtitle("") 	///
ylabel(0.00(0.001)0.005, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Transport.") legend(order(7 "Man (No Fem. Occ)" 8 "Woman (No Fem. Occ)" 9 "Man (Fem. Occ)" 10  "Woman (Fem. Occ)") rows(4))
graph save g4.gph, replace

twoway scatter pad id if id == 16.5 || scatter pad id if id == 20.5 || ///
rspike pred_ll pred_ul id if id == 17, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 18, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 19, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 20, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 17, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 18, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 19, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 20, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("") ysize(7)							///
  xtitle("") 	///
ylabel(0.04(0.005)0.06, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Urban Dev.") legend(order(7 "Man (No Fem. Occ)" 8 "Woman (No Fem. Occ)" 9 "Man (Fem. Occ)" 10  "Woman (Fem. Occ)") rows(4)) 
graph save g5.gph, replace

twoway scatter pad id if id == 20.5 || scatter pad id if id == 24.5 || ///
rspike pred_ll pred_ul id if id == 21, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 22, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 23, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 24, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 21, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 22, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 23, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 24, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("" ) ysize(7)							///
 xtitle("") 	///
ylabel(0.17(0.005)0.19, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Administration") legend(order(7 "Man (No Fem. Occ)" 8 "Woman (No Fem. Occ)" 9 "Man (Fem. Occ)" 10  "Woman (Fem. Occ)") rows(4)) 
graph save g6.gph, replace

twoway scatter pad id if id == 24.5 || scatter pad id if id == 28.5 || ///
rspike pred_ll pred_ul id if id == 25, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 26, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 27, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 28, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 25, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 26, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 27, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 28, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("" ) ysize(7)							///
  xtitle("") 	///
ylabel(0.15(0.005)0.17, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Other") legend(order(7 "Man (No Fem. Occ)" 8 "Woman (No Fem. Occ)" 9 "Man (Fem. Occ)" 10  "Woman (Fem. Occ)") rows(4)) 
graph save g7.gph, replace

graph combine g1.gph g2.gph g3.gph, rows(1) iscale(0.7) 
*graph export "Text/Figures/6category_femininespending_femoccinter.pdf", as(pdf) replace
graph combine g4.gph g5.gph g6.gph g7.gph, rows(1) iscale(0.7) 
*graph export "Text/Figures/6category_otherspending_femoccinter.pdf", as(pdf) replace

restore
cap drop *_ul *_mid *_ll *_m *_f



* -------------------------------------------------------------------
* Figure S4 (IN SI)
* -------------------------------------------------------------------
* Using 3 categories, see if women councilors x woman mayor has an effect
* Simulation part:
drop stub_* // drop old sims

estsimp sureg (fem_mas mayorfemale femmayor_womencounc $fullcontrols $Y_fe) /// 
(neut_mas mayorfemale femmayor_womencounc $fullcontrols $Y_fe), genname(stub_)

setx mean // set everything to means

* Scen 1: E[s] | male, 10% women councilors
setx mayorfemale 0 // scenario = male
setx femmayor_womencounc 0 // scenario = male, 10% women councilors
setx pctwomencouncillors 0
setx
simqi, ev genev(fem_mas_m_lo neut_mas_m_lo) // E[s] | male, 10% women councilors
* Scen 2: E[s] | male, 90% women councilors
setx mayorfemale 0 // scenario = male
setx femmayor_womencounc 0 // scenario = male, 90% women councilors
setx pctwomencouncillors 28.57
setx
simqi, ev genev(fem_mas_m_hi neut_mas_m_hi) // E[s] | male, 90% women councilors
* Scen 3: E[s] | female, 10% women councilors
setx mayorfemale 1 // scenario = female
setx femmayor_womencounc 0 // scenario = female, 10% women councilors
setx pctwomencouncillors 0
setx
simqi, ev genev(fem_mas_f_lo neut_mas_f_lo) // E[s] | female, 10% women councilors
* Scen 4: E[s] | male, 90% women councilors
setx mayorfemale 1 // scenario = female
setx femmayor_womencounc 28.57 // scenario = female, 90% women councilors
setx pctwomencouncillors 28.57
setx
simqi, ev genev(fem_mas_f_hi neut_mas_f_hi) // E[s] | female, 90% women councilors

* un-tranformation:
foreach i in m f {
	foreach z in hi lo {
		* generate predictions
		gen fem_`i'_`z' = exp(fem_mas_`i'_`z')/(1+(exp(fem_mas_`i'_`z')) + (exp(neut_mas_`i'_`z')))
		gen neut_`i'_`z' = exp(neut_mas_`i'_`z')/(1+(exp(fem_mas_`i'_`z')) + (exp(neut_mas_`i'_`z')))
		gen mas_`i'_`z' = 1/(1+(exp(fem_mas_`i'_`z')) + (exp(neut_mas_`i'_`z')))
	}
}

* grab predicted values foreach:
foreach var of varlist fem_m_hi - mas_f_lo	{
	_pctile `var', p(2.5,97.5) // 95% CIs
	gen `var'_ll = r(r1)
	gen `var'_ul = r(r2)
	gen `var'_mid = (`var'_ll + `var'_ul)/2	// midpoint
} 

* turn the results into a graph:
preserve
keep *ul *ll *mid
gen id = _n

gen pred_ll = .
replace pred_ll = fem_m_lo_ll in 1 // 1 = man feminine (lo)
replace pred_ll = fem_f_lo_ll in 2 // 2 = woman feminine (lo)
replace pred_ll = fem_m_hi_ll in 3 // 3 = man feminine (hi)
replace pred_ll = fem_f_hi_ll in 4 // 4 = woman feminine (hi)
replace pred_ll = mas_m_lo_ll in 5 // 5 = man masculine (lo)
replace pred_ll = mas_f_lo_ll in 6 // 6 = woman masculine (lo)
replace pred_ll = mas_m_hi_ll in 7 // 7 = man masculine (hi)
replace pred_ll = mas_f_hi_ll in 8 // 8 = woman masculine (hi)
replace pred_ll = neut_m_lo_ll in 9 // 9 = man neutral (lo)
replace pred_ll = neut_f_lo_ll in 10 // 10 = woman neutral (lo)
replace pred_ll = neut_m_hi_ll in 11 // 11 = man neutral (hi)
replace pred_ll = neut_f_hi_ll in 12 // 12 = woman neutral (hi)

gen pred_ul = .
replace pred_ul = fem_m_lo_ul in 1 // 1 = man feminine (lo)
replace pred_ul = fem_f_lo_ul in 2 // 2 = woman feminine (lo)
replace pred_ul = fem_m_hi_ul in 3 // 3 = man feminine (hi)
replace pred_ul = fem_f_hi_ul in 4 // 4 = woman feminine (hi)
replace pred_ul = mas_m_lo_ul in 5 // 5 = man masculine (lo)
replace pred_ul = mas_f_lo_ul in 6 // 6 = woman masculine (lo)
replace pred_ul = mas_m_hi_ul in 7 // 7 = man masculine (hi)
replace pred_ul = mas_f_hi_ul in 8 // 8 = woman masculine (hi)
replace pred_ul = neut_m_lo_ul in 9 // 9 = man neutral (lo)
replace pred_ul = neut_f_lo_ul in 10 // 10 = woman neutral (lo)
replace pred_ul = neut_m_hi_ul in 11 // 11 = man neutral (hi)
replace pred_ul = neut_f_hi_ul in 12 // 12 = woman neutral (hi)

gen midpt = .
replace midpt = fem_m_lo_mid in 1 // 1 = man feminine (lo)
replace midpt = fem_f_lo_mid in 2 // 2 = woman feminine (lo)
replace midpt = fem_m_hi_mid in 3 // 3 = man feminine (hi)
replace midpt = fem_f_hi_mid in 4 // 4 = woman feminine (hi)
replace midpt = mas_m_lo_mid in 5 // 5 = man masculine (lo)
replace midpt = mas_f_lo_mid in 6 // 6 = woman masculine (lo)
replace midpt = mas_m_hi_mid in 7 // 7 = man masculine (hi)
replace midpt = mas_f_hi_mid in 8 // 8 = woman masculine (hi)
replace midpt = neut_m_lo_mid in 9 // 9 = man neutral (lo)
replace midpt = neut_f_lo_mid in 10 // 10 = woman neutral (lo)
replace midpt = neut_m_hi_mid in 11 // 11 = man neutral (hi)
replace midpt = neut_f_hi_mid in 12 // 12 = woman neutral (hi)

gen pad = . // need pad just above and below each category
loc idval = .5
forv i = 100/112 { // 100 is just an arbitrary # away from the important ones that contain PVs
	replace id = `idval' if id == `i'
	loc idval = `idval' + 1
}

twoway scatter pad id if id == .5 || scatter pad id if id == 4.5 || ///
rspike pred_ll pred_ul id if id == 1, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 2, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 3, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 4, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 1, msymbol(T) msize(large) mcolor("117 112 179") ||         	///
scatter midpt id if id == 2, msymbol(S) msize(large) mcolor("27 158 119") ||				///
scatter midpt id if id == 3, msymbol(Th) msize(large) mcolor("117 112 179") ||         	///
scatter midpt id if id == 4, msymbol(Sh) msize(large) mcolor("27 158 119") 			///
xlabel("") ysize(7)	ytitle("Expected Proportion of Municipal Budget")	///
  xtitle("") 	///
 	ylabel(0.56(0.01)0.62, glstyle(solid) glwidth(vvthin) glcolor(gs15))	///
title("Feminine") legend(order(7 "Man (0% W. Councilors)" 8 "Woman (0% W. Councilors)" 9 "Man (28.57% W. Councilors)" 10  "Woman (28.57% W. Councilors)") rows(4)) 
graph save g1.gph, replace

twoway scatter pad id if id == 4.5 || scatter pad id if id == 8.5 || ///
rspike pred_ll pred_ul id if id == 5, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 6, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 7, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 8, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 5, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 6, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 7, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 8, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("") ysize(7)		///
ytitle("Expected Proportion of Municipal Budget") xtitle("") 	///
 ylabel(0.16(0.01)0.22, glstyle(solid) glwidth(vvthin) glcolor(gs15))		///
title("Masculine") legend(order(7 "Man (0% W. Councilors)" 8 "Woman (0% W. Councilors)" 9 "Man (28.57% W. Councilors)" 10  "Woman (28.57% W. Councilors)") rows(4)) 
graph save g2.gph, replace

twoway scatter pad id if id == 8.5 || scatter pad id if id == 12.5 || ///
rspike pred_ll pred_ul id if id == 9, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 10, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 11, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 12, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 9, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 10, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 11, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 12, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("") ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") xtitle("") 	///
ylabel(0.20(0.01)0.25, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Neutral") legend(order(7 "Man (0% W. Councilors)" 8 "Woman (0% W. Councilors)" 9 "Man (28.57% W. Councilors)" 10  "Woman (28.57% W. Councilors)") rows(4)) 
graph save g3.gph, replace

graph combine g1.gph g2.gph g3.gph, rows(1) iscale(0.7)
*graph export "Text/Figures/3category_femcouncilinter.pdf", as(pdf) replace
restore

cap drop *_ul *_mid *_ll *_m *_f *_lo *_hi



* -------------------------------------------------------------------
* Figure S7 (IN SI)
* -------------------------------------------------------------------
* Using 3 categories, see if feminine background x woman mayor has an effect
* Simulation part:
drop stub_* // drop old sims

estsimp sureg (fem_mas mayorfemale womanmayor_femocc occ_fem $fullcontrols $Y_fe) /// 
(neut_mas mayorfemale womanmayor_femocc occ_fem $fullcontrols $Y_fe), genname(stub_)

setx mean // set everything to means

foreach var in fem_mas_m_lo neut_mas_m_lo fem_mas_m_hi neut_mas_m_hi fem_mas_f_lo neut_mas_f_lo fem_mas_f_hi neut_mas_f_hi  fem_m_hi neut_m_hi mas_m_hi fem_m_lo neut_m_lo mas_m_lo fem_f_hi neut_f_hi mas_f_hi fem_f_lo neut_f_lo mas_f_lo {
	cap drop `var'
}

* Scen 1: E[s] | male, 10% women councilors
setx mayorfemale 0 // scenario = male
setx occ_fem 0 // scenario = male, no fem occ
setx womanmayor_femocc 0
setx
simqi, ev genev(fem_mas_m_lo neut_mas_m_lo) // E[s] | male, 10% women councilors
* Scen 2: E[s] | male, 90% women councilors
setx mayorfemale 0 // scenario = male
setx occ_fem 1 // scenario = male, fem occ
setx womanmayor_femocc 0
setx
simqi, ev genev(fem_mas_m_hi neut_mas_m_hi) // E[s] | male, 90% women councilors
* Scen 3: E[s] | female, 10% women councilors
setx mayorfemale 1 // scenario = female
setx occ_fem 0 // scenario = female, no fem occ
setx womanmayor_femocc 0
setx
simqi, ev genev(fem_mas_f_lo neut_mas_f_lo) // E[s] | female, 10% women councilors
* Scen 4: E[s] | male, 90% women councilors
setx mayorfemale 1 // scenario = female
setx occ_fem 1 // scenario = female, fem occ
setx womanmayor_femocc 1
setx
simqi, ev genev(fem_mas_f_hi neut_mas_f_hi) // E[s] | female, 90% women councilors

* un-tranformation:
foreach i in m f {
	foreach z in hi lo {
		* generate predictions
		gen fem_`i'_`z' = exp(fem_mas_`i'_`z')/(1+(exp(fem_mas_`i'_`z')) + (exp(neut_mas_`i'_`z')))
		gen neut_`i'_`z' = exp(neut_mas_`i'_`z')/(1+(exp(fem_mas_`i'_`z')) + (exp(neut_mas_`i'_`z')))
		gen mas_`i'_`z' = 1/(1+(exp(fem_mas_`i'_`z')) + (exp(neut_mas_`i'_`z')))
	}
}

drop *_ll *_ul *_mid
* grab predicted values foreach:
foreach var of varlist fem_m_hi - mas_f_lo	{
	_pctile `var', p(2.5,97.5) // 95% CIs
	gen `var'_ll = r(r1)
	gen `var'_ul = r(r2)
	gen `var'_mid = (`var'_ll + `var'_ul)/2	// midpoint
} 

* turn the results into a graph:
preserve
keep *ul *ll *mid
gen id = _n

gen pred_ll = .
replace pred_ll = fem_m_lo_ll in 1 // 1 = man feminine (lo)
replace pred_ll = fem_f_lo_ll in 2 // 2 = woman feminine (lo)
replace pred_ll = fem_m_hi_ll in 3 // 3 = man feminine (hi)
replace pred_ll = fem_f_hi_ll in 4 // 4 = woman feminine (hi)
replace pred_ll = mas_m_lo_ll in 5 // 5 = man masculine (lo)
replace pred_ll = mas_f_lo_ll in 6 // 6 = woman masculine (lo)
replace pred_ll = mas_m_hi_ll in 7 // 7 = man masculine (hi)
replace pred_ll = mas_f_hi_ll in 8 // 8 = woman masculine (hi)
replace pred_ll = neut_m_lo_ll in 9 // 9 = man neutral (lo)
replace pred_ll = neut_f_lo_ll in 10 // 10 = woman neutral (lo)
replace pred_ll = neut_m_hi_ll in 11 // 11 = man neutral (hi)
replace pred_ll = neut_f_hi_ll in 12 // 12 = woman neutral (hi)

gen pred_ul = .
replace pred_ul = fem_m_lo_ul in 1 // 1 = man feminine (lo)
replace pred_ul = fem_f_lo_ul in 2 // 2 = woman feminine (lo)
replace pred_ul = fem_m_hi_ul in 3 // 3 = man feminine (hi)
replace pred_ul = fem_f_hi_ul in 4 // 4 = woman feminine (hi)
replace pred_ul = mas_m_lo_ul in 5 // 5 = man masculine (lo)
replace pred_ul = mas_f_lo_ul in 6 // 6 = woman masculine (lo)
replace pred_ul = mas_m_hi_ul in 7 // 7 = man masculine (hi)
replace pred_ul = mas_f_hi_ul in 8 // 8 = woman masculine (hi)
replace pred_ul = neut_m_lo_ul in 9 // 9 = man neutral (lo)
replace pred_ul = neut_f_lo_ul in 10 // 10 = woman neutral (lo)
replace pred_ul = neut_m_hi_ul in 11 // 11 = man neutral (hi)
replace pred_ul = neut_f_hi_ul in 12 // 12 = woman neutral (hi)

gen midpt = .
replace midpt = fem_m_lo_mid in 1 // 1 = man feminine (lo)
replace midpt = fem_f_lo_mid in 2 // 2 = woman feminine (lo)
replace midpt = fem_m_hi_mid in 3 // 3 = man feminine (hi)
replace midpt = fem_f_hi_mid in 4 // 4 = woman feminine (hi)
replace midpt = mas_m_lo_mid in 5 // 5 = man masculine (lo)
replace midpt = mas_f_lo_mid in 6 // 6 = woman masculine (lo)
replace midpt = mas_m_hi_mid in 7 // 7 = man masculine (hi)
replace midpt = mas_f_hi_mid in 8 // 8 = woman masculine (hi)
replace midpt = neut_m_lo_mid in 9 // 9 = man neutral (lo)
replace midpt = neut_f_lo_mid in 10 // 10 = woman neutral (lo)
replace midpt = neut_m_hi_mid in 11 // 11 = man neutral (hi)
replace midpt = neut_f_hi_mid in 12 // 12 = woman neutral (hi)

gen pad = . // need pad just above and below each category
loc idval = .5
forv i = 100/112 { // 100 is just an arbitrary # away from the important ones that contain PVs
	replace id = `idval' if id == `i'
	loc idval = `idval' + 1
}

twoway scatter pad id if id == .5 || scatter pad id if id == 4.5 || ///
rspike pred_ll pred_ul id if id == 1, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 2, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 3, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 4, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 1, msymbol(T) msize(large) mcolor("117 112 179") ||         	///
scatter midpt id if id == 2, msymbol(S) msize(large) mcolor("27 158 119") ||				///
scatter midpt id if id == 3, msymbol(Th) msize(large) mcolor("117 112 179") ||         	///
scatter midpt id if id == 4, msymbol(Sh) msize(large) mcolor("27 158 119") 			///
xlabel("") ysize(7)	ytitle("Expected Proportion of Municipal Budget")	///
  xtitle("") 	///
 	ylabel(0.56(0.01)0.62, glstyle(solid) glwidth(vvthin) glcolor(gs15))	///
title("Feminine") legend(order(7 "Man (No Fem. Occ)" 8 "Woman (No Fem. Occ)" 9 "Man (Fem. Occ)" 10  "Woman (Fem. Occ)") rows(4)) 
graph save g1.gph, replace

twoway scatter pad id if id == 4.5 || scatter pad id if id == 8.5 || ///
rspike pred_ll pred_ul id if id == 5, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 6, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 7, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 8, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 5, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 6, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 7, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 8, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("") ysize(7)		///
ytitle("Expected Proportion of Municipal Budget") xtitle("") 	///
 ylabel(0.16(0.01)0.22, glstyle(solid) glwidth(vvthin) glcolor(gs15))		///
title("Masculine") legend(order(7 "Man (No Fem. Occ)" 8 "Woman (No Fem. Occ)" 9 "Man (Fem. Occ)" 10  "Woman (Fem. Occ)") rows(4)) 
graph save g2.gph, replace

twoway scatter pad id if id == 8.5 || scatter pad id if id == 12.5 || ///
rspike pred_ll pred_ul id if id == 9, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 10, lwidth(thick) lcolor("27 158 119") || ///
rspike pred_ll pred_ul id if id == 11, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 12, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 9, msymbol(T) msize(large) mcolor("117 112 179") ||	///
scatter midpt id if id == 10, msymbol(S) msize(large) mcolor("27 158 119") ||		///
scatter midpt id if id == 11, msymbol(Th) msize(large) mcolor("117 112 179") ||      	///
scatter midpt id if id == 12, msymbol(Sh) msize(large) mcolor("27 158 119") 		///
xlabel("") ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") xtitle("") 	///
ylabel(0.20(0.01)0.25, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Neutral") legend(order(7 "Man (No Fem. Occ)" 8 "Woman (No Fem. Occ)" 9 "Man (Fem. Occ)" 10  "Woman (Fem. Occ)") rows(4)) 
graph save g3.gph, replace

graph combine g1.gph g2.gph g3.gph, rows(1) iscale(0.7) 
*graph export "Text/Figures/3category_femoccinter.pdf", as(pdf) replace
restore

drop *_ul *_mid *_ll *_lo *_hi




* -------------------------------------------------------------
* SI Table S7: Education as baseline
* -------------------------------------------------------------
eststo clear
eststo: sureg (hlt_edu mayorfemale $fullcontrols $Y_fe) /// 
	(asst_edu mayorfemale $fullcontrols $Y_fe)  ///
	(trp_edu mayorfemale $fullcontrols $Y_fe)  ///
	(adm_edu mayorfemale $fullcontrols $Y_fe)  ///
	(urb_edu mayorfemale $fullcontrols $Y_fe) ///
	(oth_edu mayorfemale $fullcontrols $Y_fe) 
$tablemaker

* -------------------------------------------------------------
* SI Table S8: Health as baseline
* -------------------------------------------------------------
eststo clear
eststo: sureg (edu_hlt mayorfemale $fullcontrols $Y_fe) /// 
	(asst_hlt mayorfemale $fullcontrols $Y_fe)  ///
	(trp_hlt mayorfemale $fullcontrols $Y_fe)  ///
	(adm_hlt mayorfemale $fullcontrols $Y_fe)  ///
	(urb_hlt mayorfemale $fullcontrols $Y_fe) ///
	(oth_hlt mayorfemale $fullcontrols $Y_fe) 
$tablemaker

* -------------------------------------------------------------
* SI Table S9: Social Assistance as baseline
* -------------------------------------------------------------
eststo clear
eststo: sureg (edu_asst mayorfemale $fullcontrols $Y_fe) /// 
	(hlt_asst mayorfemale $fullcontrols $Y_fe)  ///
	(trp_asst mayorfemale $fullcontrols $Y_fe)  ///
	(adm_asst mayorfemale $fullcontrols $Y_fe)  ///
	(urb_asst mayorfemale $fullcontrols $Y_fe) ///
	(oth_asst mayorfemale $fullcontrols $Y_fe) 
$tablemaker




* -------------------------------------------------------------------
* Figures S1, S2, S3 (in SI)
* -------------------------------------------------------------------
* ROBUSTNESS CHECK: COLLAPSE BY MUNICIPALITY-MAYOR
collapse fem_mas neut_mas edu_oth hlt_oth asst_oth trp_oth adm_oth urb_oth mayorfemale $fullcontrols, by(ibgecode term20052008)

estsimp sureg (fem_mas mayorfemale $fullcontrols) /// 
(neut_mas mayorfemale $fullcontrols), genname(stub_)

setx mean // set everything to means
setx mayorfemale 0 // scenario = male
setx
simqi, ev genev(fem_mas_m neut_mas_m) // E[s] | male
 
setx mayorfemale 1 // scenaro = female
simqi, ev genev(fem_mas_f neut_mas_f) // E[s] | female

* Untransformation:
gen fem_m = exp(fem_mas_m)/(1 + exp(fem_mas_m) + exp(neut_mas_m))
gen neut_m = exp(neut_mas_m)/(1 + exp(fem_mas_m) + exp(neut_mas_m))
gen mas_m = 1/(1 + exp(fem_mas_m) + exp(neut_mas_m))
gen fem_f = exp(fem_mas_f)/(1 + exp(fem_mas_f) + exp(neut_mas_f))
gen neut_f = exp(neut_mas_f)/(1 + exp(fem_mas_f) + exp(neut_mas_f))
gen mas_f = 1/(1 + exp(fem_mas_f) + exp(neut_mas_f))

* grab predicted values foreach:
foreach var of varlist fem_m neut_m mas_m fem_f neut_f mas_f	{
	_pctile `var', p(2.5,97.5) // 95% CIs
	gen `var'_ll = r(r1)
	gen `var'_ul = r(r2)
	gen `var'_mid = (`var'_ll + `var'_ul)/2	// midpoint
} 

* Turn them into a graph:
preserve
keep *ul *ll *mid
gen id = _n

gen pred_ll = .
replace pred_ll = fem_m_ll in 1 // 1 = man feminine
replace pred_ll = fem_f_ll in 2 // 2 = woman feminine
replace pred_ll = mas_m_ll in 3 // 3 = man masculine
replace pred_ll = mas_f_ll in 4 // 4 = woman reminine
replace pred_ll = neut_m_ll in 5 // 5 = man neutral
replace pred_ll = neut_f_ll in 6 // 6 = woman neutral

gen pred_ul = .
replace pred_ul = fem_m_ul in 1 // 1 = man feminine
replace pred_ul = fem_f_ul in 2 // 2 = woman feminine
replace pred_ul = mas_m_ul in 3 // 3 = man masculine
replace pred_ul = mas_f_ul in 4 // 4 = woman reminine
replace pred_ul = neut_m_ul in 5 // 5 = man neutral
replace pred_ul = neut_f_ul in 6 // 6 = woman neutral

gen midpt = .
replace midpt = fem_m_mid in 1 // 1 = man feminine
replace midpt = fem_f_mid in 2 // 2 = woman feminine
replace midpt = mas_m_mid in 3 // 3 = man masculine
replace midpt = mas_f_mid in 4 // 4 = woman reminine
replace midpt = neut_m_mid in 5 // 5 = man neutral
replace midpt = neut_f_mid in 6 // 6 = woman neutral

gen pad = . // need pad just above and below each category
replace id = .5 if id == 100 // 100 is just an arbitrary #
replace id = 2.5 if id == 101
replace id = 3.5 if id == 102
replace id = 4.5 if id == 103
replace id = 5.5 if id == 104
replace id = 6.5 if id == 105

twoway scatter pad id if id == .5 || scatter pad id if id == 2.5 || ///
rspike pred_ll pred_ul id if id == 1, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 2, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 1, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 2, msymbol(S) mcolor("27 158 119")				///
xlabel(1 "Man" 2 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.57(0.01)0.61, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Feminine")
graph save g1.gph, replace

twoway scatter pad id if id == 2.5 || scatter pad id if id == 4.5 || ///
rspike pred_ll pred_ul id if id == 3, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 4, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 3, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 4, msymbol(S) mcolor("27 158 119")				///
xlabel(3 "Man" 4 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.17(0.01)0.21, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Masculine")
graph save g2.gph, replace

twoway scatter pad id if id == 4.5 || scatter pad id if id == 6.5 || ///
rspike pred_ll pred_ul id if id == 5, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 6, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 5, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 6, msymbol(S) mcolor("27 158 119")				///
xlabel(5 "Man" 6 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.20(0.01)0.24, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Unclassified")
graph save g3.gph, replace
graph combine g1.gph g2.gph g3.gph, b1title("Mayor's Gender", size(medium))  rows(1) iscale(0.7)
*graph export "Text/Figures/aggregatecategories_acrossgender_collapsed.pdf", as(pdf) replace
restore
drop *_ul *_mid *_ll *_m *_f



* Simulation part for 7 category analysis):
drop stub_* // drop old sims

estsimp sureg (edu_oth mayorfemale $fullcontrols) /// 
	(hlt_oth mayorfemale $fullcontrols)  ///
	(asst_oth mayorfemale $fullcontrols)  ///
	(trp_oth mayorfemale $fullcontrols)  ///
	(adm_oth mayorfemale $fullcontrols)  ///
	(urb_oth mayorfemale $fullcontrols), genname(stub_) 
	

setx mean // set everything to means
setx mayorfemale 0 // scenario = male
setx
simqi, ev genev(edu_oth_m hlt_oth_m asst_oth_m trp_oth_m adm_oth_m urb_oth_m) // E[s] | male
 
 setx mayorfemale 1 // scenaro = female
 simqi, ev genev(edu_oth_f hlt_oth_f asst_oth_f trp_oth_f adm_oth_f urb_oth_f) // E[s] | female

* un-tranformation:
gen edu_m = exp(edu_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen hlt_m = exp(hlt_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen asst_m = exp(asst_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen trp_m = exp(trp_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen urb_m = exp(urb_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen adm_m = exp(adm_oth_m)/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))
gen oth_m = 1/(1+(exp(edu_oth_m)) + (exp(hlt_oth_m)) + (exp(asst_oth_m)) + (exp(trp_oth_m)) + (exp(adm_oth_m)) + (exp(urb_oth_m)))

gen edu_f = exp(edu_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen hlt_f = exp(hlt_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen asst_f = exp(asst_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen trp_f = exp(trp_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen urb_f = exp(urb_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen adm_f = exp(adm_oth_f)/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))
gen oth_f = 1/(1+(exp(edu_oth_f)) + (exp(hlt_oth_f)) + (exp(asst_oth_f)) + (exp(trp_oth_f)) + (exp(adm_oth_f)) + (exp(urb_oth_f)))


* grab predicted values foreach:
foreach var of varlist edu_m hlt_m asst_m trp_m urb_m adm_m oth_m edu_f hlt_f asst_f trp_f urb_f adm_f oth_f	{
	_pctile `var', p(2.5,97.5) // 95% CIs
	gen `var'_ll = r(r1)
	gen `var'_ul = r(r2)
	gen `var'_mid = (`var'_ll + `var'_ul)/2	// midpoint
} 
 
* Turn them into a graph:
preserve
keep *ul *ll *mid
gen id = _n

gen pred_ll = .
replace pred_ll = edu_m_ll in 1 // 1 = Man education
replace pred_ll = edu_f_ll in 2 // 2 = Woman education
replace pred_ll = hlt_m_ll in 3 // 3 = Man health
replace pred_ll = hlt_f_ll in 4 // 4 = Woman health
replace pred_ll = asst_m_ll in 5 // 5 = Man soc assist
replace pred_ll = asst_f_ll in 6 // 6 = Woman soc assist
replace pred_ll = trp_m_ll in 7 // 7 = man transp
replace pred_ll = trp_f_ll in 8 // 8 = woman transp
replace pred_ll = urb_m_ll in 9 // 9 = man urban
replace pred_ll = urb_f_ll in 10 // 10 = woman urban
replace pred_ll = adm_m_ll in 11 // 11 = man admin
replace pred_ll = adm_f_ll in 12 // 12 = woman admin
replace pred_ll = oth_m_ll in 13 // 13 = Man other
replace pred_ll = oth_f_ll in 14 // 14 = Woman other

gen pred_ul = .
replace pred_ul = edu_m_ul in 1 // 1 = Man education
replace pred_ul = edu_f_ul in 2 // 2 = Woman education
replace pred_ul = hlt_m_ul in 3 // 3 = Man health
replace pred_ul = hlt_f_ul in 4 // 4 = Woman health
replace pred_ul = asst_m_ul in 5 // 5 = Man soc assist
replace pred_ul = asst_f_ul in 6 // 6 = Woman soc assist
replace pred_ul = trp_m_ul in 7 // 7 = man transp
replace pred_ul = trp_f_ul in 8 // 8 = woman transp
replace pred_ul = urb_m_ul in 9 // 9 = man urban
replace pred_ul = urb_f_ul in 10 // 10 = woman urban
replace pred_ul = adm_m_ul in 11 // 11 = man admin
replace pred_ul = adm_f_ul in 12 // 12 = woman admin
replace pred_ul = oth_m_ul in 13 // 13 = Man other
replace pred_ul = oth_f_ul in 14 // 14 = Woman other

gen midpt = .
replace midpt = edu_m_mid in 1 // 1 = Man education
replace midpt = edu_f_mid in 2 // 2 = Woman education
replace midpt = hlt_m_mid in 3 // 3 = Man health
replace midpt = hlt_f_mid in 4 // 4 = Woman health
replace midpt = asst_m_mid in 5 // 5 = Man soc assist
replace midpt = asst_f_mid in 6 // 6 = Woman soc assist
replace midpt = trp_m_mid in 7 // 7 = man transp
replace midpt = trp_f_mid in 8 // 8 = woman transp
replace midpt = urb_m_mid in 9 // 9 = man urban
replace midpt = urb_f_mid in 10 // 10 = woman urban
replace midpt = adm_m_mid in 11 // 11 = man admin
replace midpt = adm_f_mid in 12 // 12 = woman admin
replace midpt = oth_m_mid in 13 // 13 = Man other
replace midpt = oth_f_mid in 14 // 14 = Woman other

gen pad = . // need pad just above and below each category
replace id = .5 if id == 100 // 100 is just an arbitrary #
replace id = 2.5 if id == 101
replace id = 3.5 if id == 102
replace id = 4.5 if id == 103
replace id = 5.5 if id == 104
replace id = 6.5 if id == 105
replace id = 7.5 if id == 106
replace id = 8.5 if id == 107
replace id = 9.5 if id == 108
replace id = 10.5 if id == 109
replace id = 11.5 if id == 110
replace id = 12.5 if id == 111
replace id = 13.5 if id == 112
replace id = 14.5 if id == 113
replace id = 15.5 if id == 114


twoway scatter pad id if id == .5 || scatter pad id if id == 2.5 || ///
rspike pred_ll pred_ul id if id == 1, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 2, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 1, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 2, msymbol(S) mcolor("27 158 119")				///
xlabel(1 "Man" 2 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.32(0.01)0.35, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Education")
graph save g1.gph, replace

twoway scatter pad id if id == 2.5 || scatter pad id if id == 4.5 || ///
rspike pred_ll pred_ul id if id == 3, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 4, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 3, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 4, msymbol(S) mcolor("27 158 119")				///
xlabel(3 "Man" 4 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.22(0.01)0.25, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Health")
graph save g2.gph, replace

twoway scatter pad id if id == 4.5 || scatter pad id if id == 6.5 || ///
rspike pred_ll pred_ul id if id == 5, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 6, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 5, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 6, msymbol(S) mcolor("27 158 119")				///
xlabel(5 "Man" 6 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.03(0.0025)0.045, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 	///
title("Social Assistance")
graph save g3.gph, replace

twoway scatter pad id if id == 6.5 || scatter pad id if id == 8.5 || ///
rspike pred_ll pred_ul id if id == 7, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 8, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 7, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 8, msymbol(S) mcolor("27 158 119")				///
xlabel(7 "Man" 8 "Woman" ) ysize(7)											///
ytitle("Expected Proportion of Municipal Budget") legend(off) xtitle("") 	///
ylabel(0.00(0.001)0.005, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Transport.")
graph save g4.gph, replace

twoway scatter pad id if id == 8.5 || scatter pad id if id == 10.5 || ///
rspike pred_ll pred_ul id if id == 9, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 10, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 9, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 10, msymbol(S) mcolor("27 158 119")				///
xlabel(9 "Man" 10 "Woman" ) ysize(7)							///
 legend(off) xtitle("") 	///
ylabel(0.04(0.005)0.06, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Urban Dev.") 
graph save g5.gph, replace

twoway scatter pad id if id == 10.5 || scatter pad id if id == 12.5 || ///
rspike pred_ll pred_ul id if id == 11, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 12, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 11, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 12, msymbol(S) mcolor("27 158 119")				///
xlabel(11 "Man" 12 "Woman" ) ysize(7)							///
 legend(off) xtitle("") 	///
ylabel(0.17(0.005)0.19, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Administration") 
graph save g6.gph, replace

twoway scatter pad id if id == 12.5 || scatter pad id if id == 14.5 || ///
rspike pred_ll pred_ul id if id == 13, lwidth(thick) lcolor("117 112 179") || ///
rspike pred_ll pred_ul id if id == 14, lwidth(thick) lcolor("27 158 119") || ///
scatter midpt id if id == 13, msymbol(T) mcolor("117 112 179") ||         	///
scatter midpt id if id == 14, msymbol(S) mcolor("27 158 119")				///
xlabel(13 "Man" 14 "Woman" ) ysize(7)							///
 legend(off) xtitle("") 	///
ylabel(0.15(0.005)0.17, glstyle(solid) glwidth(vvthin) glcolor(gs15)) 		///
title("Other") 
graph save g7.gph, replace

graph combine g1.gph g2.gph g3.gph, b1title("Mayor's Gender", size(medium))  rows(1) iscale(0.7) 
*graph export "Text/Figures/6category_femininespending_collapse.pdf", as(pdf) replace
graph combine g4.gph g5.gph g6.gph g7.gph, b1title("Mayor's Gender", size(medium))  rows(1) iscale(0.7) 
*graph export "Text/Figures/6category_otherspending_collapse.pdf", as(pdf) replace
restore









